@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2011-2013 Kevin Lange.  All rights reserved.
+ * Copyright (c) 2011-2018 K. Lange.  All rights reserved.
  *
- * Developed by:            Kevin Lange
+ * Developed by:            K. Lange
  *                          http://github.com/klange/nyancat
  *                          http://nyancat.dakko.us
  *
@@ -12,7 +12,7 @@
  * Build tools unified by:  Aaron Peschel
  *                          https://github.com/apeschel
  *
- * For a complete listing of contributers, please see the git commit history.
+ * For a complete listing of contributors, please see the git commit history.
  *
  * This is a simple telnet server / standalone application which renders the
  * classic Nyan Cat (or "poptart cat") to your terminal.
@@ -35,7 +35,7 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions and the following disclaimers in the
  *      documentation and/or other materials provided with the distribution.
- *   3. Neither the names of the Association for Computing Machinery, Kevin
+ *   3. Neither the names of the Association for Computing Machinery, K.
  *      Lange, nor the names of its contributors may be used to endorse
  *      or promote products derived from this Software without specific prior
  *      written permission.
@@ -49,9 +49,10 @@
  * WITH THE SOFTWARE.
  */
 
-#define _XOPEN_SOURCE 500
+#define _XOPEN_SOURCE 700
 #define _DARWIN_C_SOURCE 1
 #define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 #define __BSD_VISIBLE 1
 #include <ctype.h>
 #include <stdio.h>
@@ -118,7 +119,7 @@ int show_counter = 1;
 unsigned int frame_count = 0;
 
 /*
- * Clear the screen between frames (as opposed to reseting
+ * Clear the screen between frames (as opposed to resetting
  * the cursor position)
  */
 int clear_screen = 1;
@@ -347,8 +348,7 @@ void usage(char * argv[]) {
 
 int main(int argc, char ** argv) {
 
-	/* The default terminal is ANSI */
-	char term[1024] = {'a','n','s','i', 0};
+	char *term = NULL;
 	unsigned int k;
 	int ttype;
 	uint32_t option = 0, done = 0, sb_mode = 0;
@@ -485,7 +485,7 @@ int main(int argc, char ** argv) {
 								/* This was a response to the TTYPE command, meaning
 								 * that this should be a terminal type */
 								alarm(2);
-								strcpy(term, (char *)&sb[2]);
+								term = strndup((char *)&sb[2], sizeof(sb)-2);
 								done++;
 							}
 							else if (sb[0] == NAWS) {
@@ -562,10 +562,7 @@ int main(int argc, char ** argv) {
 	} else {
 		/* We are running standalone, retrieve the
 		 * terminal type from the environment. */
-		char * nterm = getenv("TERM");
-		if (nterm) {
-			strcpy(term, nterm);
-		}
+		term = getenv("TERM");
 
 		/* Also get the number of columns */
 		struct winsize w;
@@ -574,36 +571,39 @@ int main(int argc, char ** argv) {
 		terminal_height = w.ws_row;
 	}
 
-	/* Convert the entire terminal string to lower case */
-	for (k = 0; k < strlen(term); ++k) {
-		term[k] = tolower(term[k]);
-	}
+	/* Default ttype */
+	ttype = 2;
 
-	/* Do our terminal detection */
-	if (strstr(term, "xterm")) {
-		ttype = 1; /* 256-color, spaces */
-	} else if (strstr(term, "toaru")) {
-		ttype = 1; /* emulates xterm */
-	} else if (strstr(term, "linux")) {
-		ttype = 3; /* Spaces and blink attribute */
-	} else if (strstr(term, "vtnt")) {
-		ttype = 5; /* Extended ASCII fallback == Windows */
-	} else if (strstr(term, "cygwin")) {
-		ttype = 5; /* Extended ASCII fallback == Windows */
-	} else if (strstr(term, "vt220")) {
-		ttype = 6; /* No color support */
-	} else if (strstr(term, "fallback")) {
-		ttype = 4; /* Unicode fallback */
-	} else if (strstr(term, "rxvt-256color")) {
-		ttype = 1; /* xterm 256-color compatible */
-	} else if (strstr(term, "rxvt")) {
-		ttype = 3; /* Accepts LINUX mode */
-	} else if (strstr(term, "vt100") && terminal_width == 40) {
-		ttype = 7; /* No color support, only 40 columns */
-	} else if (!strncmp(term, "st", 2)) {
-		ttype = 1; /* suckless simple terminal is xterm-256color-compatible */
-	} else {
-		ttype = 2; /* Everything else */
+	if (term) {
+		/* Convert the entire terminal string to lower case */
+		for (k = 0; k < strlen(term); ++k) {
+			term[k] = tolower(term[k]);
+		}
+
+		/* Do our terminal detection */
+		if (strstr(term, "xterm")) {
+			ttype = 1; /* 256-color, spaces */
+		} else if (strstr(term, "toaru")) {
+			ttype = 1; /* emulates xterm */
+		} else if (strstr(term, "linux")) {
+			ttype = 3; /* Spaces and blink attribute */
+		} else if (strstr(term, "vtnt")) {
+			ttype = 5; /* Extended ASCII fallback == Windows */
+		} else if (strstr(term, "cygwin")) {
+			ttype = 5; /* Extended ASCII fallback == Windows */
+		} else if (strstr(term, "vt220")) {
+			ttype = 6; /* No color support */
+		} else if (strstr(term, "fallback")) {
+			ttype = 4; /* Unicode fallback */
+		} else if (strstr(term, "rxvt-256color")) {
+			ttype = 1; /* xterm 256-color compatible */
+		} else if (strstr(term, "rxvt")) {
+			ttype = 3; /* Accepts LINUX mode */
+		} else if (strstr(term, "vt100") && terminal_width == 40) {
+			ttype = 7; /* No color support, only 40 columns */
+		} else if (!strncmp(term, "st", 2)) {
+			ttype = 1; /* suckless simple terminal is xterm-256color-compatible */
+		}
 	}
 
 	int always_escape = 0; /* Used for text mode */
@@ -774,7 +774,7 @@ int main(int argc, char ** argv) {
 			newline(3);
 			printf("                             \033[1mNyancat Telnet Server\033[0m");
 			newline(2);
-			printf("                   written and run by \033[1;32mKevin Lange\033[1;34m @kevinlange\033[0m");
+			printf("                   written and run by \033[1;32mK. Lange\033[1;34m @_klange\033[0m");
 			newline(2);
 			printf("        If things don't look right, try:");
 			newline(1);
